@@ -1,22 +1,26 @@
 # /*
-# * Copyright © 2020 VMware, Inc.
-# * SPDX-License-Identifier: Apache-2.0 OR GPL-2.0-only
-# */
-# pylint: disable=invalid-name,missing-docstring
-import subprocess
+#  * Copyright © 2020 VMware, Inc.
+#  * SPDX-License-Identifier: Apache-2.0 OR GPL-2.0-only
+#  */
+#
+
+import copy
+import crypt
+import glob
+import json
 import os
 import re
-import glob
-import crypt
+import shlex
 import shutil
 import ssl
-import requests
-import copy
-import json
+import subprocess
+import tempfile
 from urllib.parse import urlparse
 from urllib.request import urlopen
-from OpenSSL.crypto import load_certificate, FILETYPE_PEM
+
+import requests
 import yaml
+from OpenSSL.crypto import FILETYPE_PEM, load_certificate
 
 
 class CommandUtils(object):
@@ -24,32 +28,97 @@ class CommandUtils(object):
         self.logger = logger
         self.hostRpmIsNotUsable = -1
 
+    def _update_environment_from_file(self, env_file_path):
+        """Update environment variables from a temporary file."""
+        try:
+            if not os.path.exists(env_file_path):
+                self.logger.debug("Environment file does not exist, skipping environment update")
+                return
+
+            env_vars = {}
+            with open(env_file_path, 'rb') as f:
+                content = f.read().decode('utf-8', errors='replace')
+
+            # Split on null bytes for env -0 output
+            for line in content.split('\0'):
+                if line and '=' in line:
+                    key, _, value = line.partition('=')
+                    env_vars[key.strip()] = value.strip()
+
+            if env_vars:
+                os.environ.update(env_vars)
+                self.logger.debug(f"Updated environment with {len(env_vars)} variables")
+
+        except Exception as e:
+            self.logger.error(f"Failed to update environment from file: {e}")
+
     def run(self, cmd, update_env=False):
-        self.logger.info(f"running {cmd}")
-        use_shell = not isinstance(cmd, list)
-        process = subprocess.Popen(
-            cmd, shell=use_shell, text=True,
-            stdout=subprocess.PIPE, stderr=subprocess.PIPE
-        )
-        out, err = process.communicate()
-        if out != "":
-            self.logger.info(out)
+        env_file_path = None
+        try:
+            self.logger.info(f"running {cmd}")
+            use_shell = not isinstance(cmd, list)
+
+            # If we need to update environment, modify the command to write env vars to a temp file
             if update_env:
-                os.environ.clear()
-                os.environ.update(
-                    dict(
-                        line.partition("=")[::2]
-                        for line in out.split("\0")
-                        if line
-                    )
-                )
-        process.wait()
-        retval = process.returncode
-        if retval != 0:
-            self.logger.info("Command failed: {}".format(cmd))
-            self.logger.info("Error code: {}".format(retval))
-            self.logger.error(err)
-        return retval
+                # Create a temporary file for environment variables
+                env_fd, env_file_path = tempfile.mkstemp(prefix='photon_installer_env_', suffix='.txt')
+                os.close(env_fd)  # Close the file descriptor, we'll write to it via shell redirection
+
+                if use_shell:
+                    # For shell commands, append environment capture to the command
+                    if isinstance(cmd, str):
+                        # Wrap the command in a subshell and capture environment after execution
+                        cmd = f"bash -c {shlex.quote(cmd + f'; env -0 > {env_file_path}')}"
+                else:
+                    # For list commands, execute them directly and then capture environment
+                    # We'll use a different approach - run the command and then capture env
+                    # Convert list to a proper shell command with environment capture
+                    if len(cmd) >= 3 and cmd[0] == "/bin/bash" and cmd[1] == "-c":
+                        # This is a bash -c command, we can extend it
+                        script_content = cmd[2] + f'; env -0 > {env_file_path}'
+                        cmd = ["/bin/bash", "-c", script_content]
+                    else:
+                        # Regular command list - convert to shell with proper escaping
+                        escaped_cmd = ' '.join(shlex.quote(arg) for arg in cmd)
+                        cmd = f"bash -c {shlex.quote(escaped_cmd + f'; env -0 > {env_file_path}')}"
+                        use_shell = True
+
+            with subprocess.Popen(
+                cmd, shell=use_shell, text=True,
+                stdout=subprocess.PIPE, stderr=subprocess.STDOUT
+            ) as process:
+                out = ""
+                if process.stdout:
+                    for line in process.stdout:
+                        self.logger.info(line.rstrip())
+                        out += line
+
+                retval = process.wait()
+
+                # Update environment from the temporary file if needed
+                if update_env and env_file_path:
+                    self._update_environment_from_file(env_file_path)
+
+                if retval != 0:
+                    self.logger.error(f"Command failed: {cmd}")
+                    self.logger.error(f"Error code: {retval}")
+
+                return retval
+
+        except subprocess.SubprocessError as e:
+            self.logger.error(f"Subprocess error running {cmd}: {e}")
+            return -1
+        except Exception as e:
+            self.logger.error(f"Unexpected error running {cmd}: {e}")
+            return -1
+        finally:
+            # Clean up the temporary file if it was created
+            if env_file_path and os.path.exists(env_file_path):
+                try:
+                    os.unlink(env_file_path)
+                    self.logger.debug(f"Cleaned up temporary environment file: {env_file_path}")
+                except Exception as e:
+                    self.logger.warning(f"Failed to remove temporary environment file {env_file_path}: {e}")
 
     def run_in_chroot(self, chroot_path, cmd, update_env=False):
         # Use short command here. Initial version was:
@@ -80,7 +149,7 @@ class CommandUtils(object):
     def _requests_get(url, verify):
         try:
             r = requests.get(url, verify=verify, stream=True, timeout=5.0)
-        except Exception as e:
+        except Exception:
             return None
         return r
 
@@ -112,7 +181,7 @@ class CommandUtils(object):
         try:
             result = urlparse(url)
             return all([result.scheme, result.netloc])
-        except:
+        except Exception:
             return False
 
     # read json from a file or URL
@@ -133,7 +202,7 @@ class CommandUtils(object):
         # Check URL
         try:
             u = urlparse(url)
-        except:
+        except Exception:
             return False, "Failed to parse URL"
         if not all([u.scheme, u.netloc]):
             return False, "Invalid URL"
@@ -149,10 +218,10 @@ class CommandUtils(object):
                 port = 443
             try:
                 pem = ssl.get_server_certificate((u.netloc, port))
-                cert = load_certificate(FILETYPE_PEM, pem)
+                cert = load_certificate(FILETYPE_PEM, pem.encode('utf-8'))
                 fp = cert.digest("sha1").decode()
-            except:
-                return False, "Failed to get server certificate"
+            except Exception as e:
+                return False, f"Failed to get server certificate: {e}"
             if ask_fn is not None:
                 if not ask_fn(fp):
                     return False, "Aborted on user request"
@@ -205,7 +274,7 @@ class CommandUtils(object):
         default = None
         key = node.value
 
-        assert type(key) is str, f"param name must be a string"
+        assert type(key) is str, "param name must be a string"
 
         if '=' in key:
             key, default = [t.strip() for t in key.split('=', maxsplit=1)]
@@ -224,10 +293,13 @@ class CommandUtils(object):
     def readConfig(stream, params={}):
         config = None
 
-        yaml_loader = yaml.SafeLoader
-        yaml_loader.app_params = params
-        yaml.add_constructor("!param", CommandUtils._yaml_param, Loader=yaml_loader)
-        config = yaml.load(stream, Loader=yaml_loader)
+        class ParamLoader(yaml.SafeLoader):
+            def __init__(self, stream):
+                super().__init__(stream)
+                self.app_params = params
+
+        yaml.add_constructor("!param", CommandUtils._yaml_param, Loader=ParamLoader)
+        config = yaml.load(stream, Loader=ParamLoader)
 
         return config
 
