@@ -1,15 +1,14 @@
 #
 # Copyright © 2023 VMware, Inc.
 # SPDX-License-Identifier: Apache-2.0 OR GPL-2.0-only
-# pylint: disable=invalid-name,missing-docstring,no-member
+#
 import os
-import stat
 import shutil
+import stat
 import subprocess
 
-from tdnf import Tdnf, create_repo_conf
 from commandutils import CommandUtils
-
+from tdnf import Tdnf, create_repo_conf
 
 INITRD_FSTAB = """# Begin /etc/fstab for a bootable CD
 
@@ -61,7 +60,6 @@ class IsoInitrd:
             reposdir=self.working_dir,
             releasever=self.photon_release_version,
             installroot=self.initrd_path,
-            docker_image=f"photon:{self.photon_release_version}",
         )
 
     def create_installer_script(self):
@@ -188,15 +186,17 @@ class IsoInitrd:
         self.cmd_util.remove_files(files_to_remove)
 
     def install_initrd_packages(self):
-        tdnf_args = ["install"] + self.initrd_pkgs
-        mount_dirs = []
+        # nogpgcheck to work around installing locally built packages, like photon-os-installer
+        tdnf_args = ["--nogpgcheck", "install"] + self.initrd_pkgs
+        # mount_dirs = []
         if self.ostree_iso:
             self.tdnf.config_file = None
             self.tdnf.reposdir = None
         else:
-            mount_dirs = [self.rpms_path, self.working_dir]
+            # mount_dirs = [self.rpms_path, self.working_dir]
+            pass
 
-        self.tdnf.run(tdnf_args, directories=mount_dirs)
+        self.tdnf.run(tdnf_args, do_json=False)
 
     def prepare_installer_dir(self):
         installer_dir = f"{self.initrd_path}/installer"
